@@ -62,6 +62,7 @@ class CommandRunner():
 
         p = subprocess.Popen(
             cmd_with_progress,
+            stdin=subprocess.PIPE,    # Apply stdin isolation by creating separate pipe.
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
             universal_newlines=False
@@ -99,6 +100,7 @@ class CommandRunner():
 
         p = subprocess.Popen(
             self.cmd,
+            stdin=subprocess.PIPE,    # Apply stdin isolation by creating separate pipe.
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE,
             universal_newlines=False
@@ -185,7 +187,7 @@ def ffmpeg_has_loudnorm():
     if 'loudnorm' in output:
         return True
     else:
-        logger.warning(
+        logger.error(
             "Your ffmpeg version does not support the 'loudnorm' filter. "
             "Please make sure you are running ffmpeg v3.1 or above."
         )
